<?php

    namespace common\models;

    use Yii;
    use yii\base\Model;
    use yii\bootstrap\ActiveForm;
    use yii\data\ActiveDataProvider;
    use common\models\Blog;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;

    /**
     * BlogSearch represents the model behind the search form about `common\models\Blog`.
     */
    class BlogSearch extends Blog
    {

        public $date_add_from;
        public $date_add_to;
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'blog_id',
                        'user_id',
                        'user_add_id',
                        'view_count',
                    ],
                    'integer',
                ],
                [
                    [
                        'name',
                        'link',
                        'date_add',
                        'description',
                        'cover',
                        'date_add_from',
                        'date_add_to',
                    ],
                    'safe',
                ],
                [
                    [
                        'date_add_to',
                    ],
                    'compare',
                    'compareAttribute' => 'date_add_from',
                    'operator' => '>=',
                ],
                [
                    [
                        'date_add_from',
                    ],
                    'compare',
                    'compareValue' => date('Y-m-d'),
                    'operator' => '<=',
                ],
            ];
        }

        /**
         * @inheritdoc
         */
        public function scenarios()
        {
            // bypass scenarios() implementation in the parent class
            return Model::scenarios();
        }

        /**
         * Creates data provider instance with search query applied
         *
         * @param array $params
         *
         * @return ActiveDataProvider
         */
        public function search($params)
        {
            $query = Blog::find();

            // add conditions that should always apply here

            $dataProvider = new ActiveDataProvider([
                'query' => $query,
            ]);

            $this->load($params);

            if(!$this->validate()) {
                // uncomment the following line if you do not want to return any records when validation fails
                // $query->where('0=1');
                return $dataProvider;
            }

            $query->andWhere([ 'user_id' => \Yii::$app->user->getId() ]);

            // grid filtering conditions
            $query->andFilterWhere([
                'blog_id'     => $this->blog_id,
                'user_add_id' => $this->user_add_id,
                'view_count'  => $this->view_count,
            ]);

            if(!empty($this->date_add_from) && !empty($this->date_add_to)) {
                $query->andWhere([
                    'between',
                    'date_add',
                    $this->date_add_from,
                    (new \DateTime($this->date_add_to))->modify('+1 day')->format('Y-m-d'),
                ]);
            } elseif(!empty($this->date_add_from)) {
                $query->andWhere([
                    '>=',
                    'date_add',
                    $this->date_add_from,
                ]);
            } elseif(!empty($this->date_add_to)) {
                $query->andWhere([
                    '<=',
                    'date_add',
                    (new \DateTime($this->date_add_to))->modify('+1 day')->format('Y-m-d'),
                ]);
            }

            $query->andFilterWhere([
                'like',
                'LOWER(name)',
                mb_strtolower($this->name),
            ])
                  ->andFilterWhere([
                      'like',
                      'description',
                      $this->description,
                  ])
                  ->andFilterWhere([
                      'like',
                      'cover',
                      $this->cover,
                  ]);

            return $dataProvider;
        }

        public function searchByUser($params)
        {
            $query = $this->search($params);

        }
    }
