<?php

    namespace common\models;

    use Yii;
    use yii\base\Model;
    use yii\data\ActiveDataProvider;
    use common\models\Gallery;

    /**
     * GallerySearch represents the model behind the search form about `common\models\Gallery`.
     */
    class GallerySearch extends Gallery
    {

        public $date_add_from;
        public $date_add_to;
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'gallery_id',
                        'user_add_id',
                        'type',
                    ],
                    'integer',
                ],
                [
                    [
                        'name',
                        'date_add',
                        'cover',
                        'photo',
                        'date_add_from',
                        'date_add_to',
                    ],
                    'safe',
                ],
                [
                    [
                        'date_add_from',
                    ],
                    'default',
                    'value' => date('Y-m-d', 0),
                ],
                [
                    [
                        'date_add_to',
                    ],
                    'default',
                    'value' => date('Y-m-d'),
                ],
            ];
        }

        /**
         * @inheritdoc
         */
        public function scenarios()
        {
            // bypass scenarios() implementation in the parent class
            return Model::scenarios();
        }

        /**
         * Creates data provider instance with search query applied
         *
         * @param array $params
         *
         * @return ActiveDataProvider
         */
        public function search($params)
        {
            $query = Gallery::find();

            // add conditions that should always apply here

            $dataProvider = new ActiveDataProvider([
                'query' => $query,
            ]);

            $portfolioGallery = PortfolioGallery::find()->select(['gallery_id'])->where(['user_id' => \Yii::$app->user->id])->asArray()->column();

            $query->andWhere(['not in', 'gallery_id', $portfolioGallery]);

            $this->load($params);

            if(!$this->validate()) {
                // uncomment the following line if you do not want to return any records when validation fails
                // $query->where('0=1');
                return $dataProvider;
            }

            $query->andWhere([
                'user_id' => \Yii::$app->user->getId(),
            ]);

            // grid filtering conditions
            $query->andFilterWhere([
                'gallery_id' => $this->gallery_id,
                'date_add' => $this->date_add,
                'user_add_id' => $this->user_add_id,
                'type' => $this->type,
            ]);

            $query->andFilterWhere([
                'between',
                'date_add',
                $this->date_add_from,
                (new \DateTime($this->date_add_to))->modify('+1 day')->format('Y-m-d')
            ]);


            $query->andFilterWhere([
                'like',
                'LOWER(name)',
                mb_strtolower($this->name, 'UTF-8')

            ])
                  ->andFilterWhere([
                      'like',
                      'cover',
                      $this->cover,
                  ])
                  ->andFilterWhere([
                      'like',
                      'photo',
                      $this->photo,
                  ]);

            return $dataProvider;
        }
    }
