<?php

    namespace common\models;

    use Yii;
    use yii\base\Model;
    use yii\data\ActiveDataProvider;
    use common\models\Project;

    /**
     * ProjectSearch represents the model behind the search form about `common\models\Project`.
     */
    class ProjectSearch extends Project
    {

        public $date_add_from;
        public $date_add_to;
        public $budget_approx;
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'project_id',
                        'project_pid',
                        'user_add_id',
                        'payment_variant',
                        'deadline',
                        'contractual',
                    ],
                    'integer',
                ],
                [
                    [
                        'name',
                        'link',
                        'date_add',
                        'date_end',
                        'budget',
                        'budget_approx',
                        'city',
                        'street',
                        'house',
                        'description',
                        'file',
                        'specializationString',
                        'date_add_from',
                        'date_add_to',
                    ],
                    'safe',
                ],
                [
                    [ 'view_count' ],
                    'number',
                ],
                [
                    [
                        'date_add_from',
                    ],
                    'default',
                    'value' => date('Y-m-d', 0),
                ],
                [
                    [
                        'date_add_to',
                    ],
                    'default',
                    'value' => date('Y-m-d'),
                ],
            ];
        }

        /**
         * @inheritdoc
         */
        public function scenarios()
        {
            // bypass scenarios() implementation in the parent class
            return Model::scenarios();
        }

        /**
         * Creates data provider instance with search query applied
         *
         * @param array $params
         *
         * @return ActiveDataProvider
         */
        public function search($params)
        {
            $query = Project::find()->with('comments');

            // add conditions that should always apply here

            $dataProvider = new ActiveDataProvider([
                'query' => $query,
            ]);

            $this->load($params);

            if(!$this->validate()) {
                // uncomment the following line if you do not want to return any records when validation fails
                // $query->where('0=1');
                return $dataProvider;
            }

            $query2 = [ ];
            if(!empty( $this->specializationString )) {
                $query2 = Project::find()
                                 ->select([ 'project.project_id' ], 'DISTINCT')
                                 ->joinWith([ 'specializations' ])
                                 ->where([
                                     'like',
                                     'LOWER(specialization_name)',
                                     mb_strtolower($this->specializationString),
                                 ])
                                 ->asArray()
                                 ->column();
            }

            $query->andWhere([ 'user_id' => \Yii::$app->user->getId() ]);

            // grid filtering conditions
            $query->andFilterWhere([
                'project_id'      => $this->project_id,
                'project_pid'     => $this->project_pid,
                'date_add'        => $this->date_add,
                'date_end'        => $this->date_end,
                'user_add_id'     => $this->user_add_id,
                'view_count'      => $this->view_count,
                'payment_variant' => $this->payment_variant,
                'deadline'        => $this->deadline,
            ]);

            $query->andFilterWhere([
                'between',
                'date_add',
                $this->date_add_from,
                (new \DateTime($this->date_add_to))->modify('+1 day')->format('Y-m-d'),
            ]);

            if(!empty($this->specializationString)) {
                $query->andWhere(
                    [
                        'project_id' => $query2,
                    ]
                );
            }

            $query->andFilterWhere([
                'like',
                'LOWER(name)',
                mb_strtolower($this->name),
            ])
                  ->andFilterWhere([
                      'like',
                      'budget',
                      $this->budget,
                  ])
                  ->andFilterWhere([
                      'like',
                      'LOWER(city)',
                      mb_strtolower($this->city),
                  ])
                  ->andFilterWhere([
                      'like',
                      'street',
                      $this->street,
                  ])
                  ->andFilterWhere([
                      'like',
                      'house',
                      $this->house,
                  ])
                  ->andFilterWhere([
                      'like',
                      'description',
                      $this->description,
                  ])
                  ->andFilterWhere([
                      'like',
                      'file',
                      $this->file,
                  ]);

            if(!empty($this->budget_approx)) {
                $query->andWhere(['between', 'budget', ($this->budget_approx - ($this->budget_approx/10)), ($this->budget_approx + ($this->budget_approx/10))]);
                $query->andWhere(['not', ['contractual' => 1]]);
            }

            if($this->contractual == 1) {
                $query->andWhere(['contractual' => 1]);
            } elseif($this->contractual == 2) {
                $query->andWhere(['not', ['contractual' => 1]]);
            }

            return $dataProvider;
        }
    }
