<?php
    /**
     * @var View               $this
     * @var User               $company
     * @var ActiveDataProvider $projectProvider
     * @var ActiveDataProvider $blogProvider
     * @var ActiveDataProvider $commentProvider
     */
    use common\models\Specialization;
    use common\models\User;
    use yii\data\ActiveDataProvider;
    use yii\helpers\ArrayHelper;
    use yii\helpers\Html;
    use yii\web\View;
    use yii\widgets\ListView;

    $this->params[ 'company' ] = $company;
    $this->title = 'Proektant.net';
?>
    <div class="company-performer-title style">О компании</div>
    <div class="company-performer-txt style">
        <?php
            if(!empty( $company->userInfo->about )) {
                echo $company->userInfo->about;
            } else {
                echo Yii::t('app', 'Not found');
            }
        ?>
    </div>
<?php
    /*====Blocks for layout====*/
    /*
     * Use $projectProvider to obtain models for this block
     */
    $this->beginBlock('our_objects');
?>
    <div class="section-box-18">
        <div class="box-wr">
            <div class="box-all">
                <div class="company-performer-type-title style">Наши объекты (<?= $projectProvider->totalCount ?>)</div>
                <div class="settings-map-ul company_map_time" data-map="company_map">
                    <ul>
                        <li>
                            <a href="#" class="active company_map_time_link" data-start="<?= strtotime('-1 years') ?>"><span>Последний год</span></a>
                        </li>
                        <li>
                            <a href="#" class="company_map_time_link" data-start="<?= strtotime('-5 years') ?>"><span>Последние пять лет</span></a>
                        </li>
                        <li>
                            <a href="#" class="company_map_time_link" data-start="0"><span>Весь период</span></a>
                        </li>
                    </ul>
                </div>
                <div class="company-performer-type-map style">
                    <div class="section-box-map">
                        <div class="shadow-map"></div>
                        <div id="map_company" style="width: 100%; height:100%;" data-user="<?= $company->id ?>"></div>
                        <div class="company-performer-map-menu">
                            <?php
                                $specializations = Specialization::find()
                                                                 ->where([ 'specialization_pid' => 0 ])
                                                                 ->with('children.children')
                                                                 ->orderBy('specialization_id')
                                                                 ->all();
                            ?>
                            <ul class="content-menu-first">
                                <?php
                                    foreach($specializations as $specialization) {
                                        ?>
                                        <li data-img="<?= $specialization->image ?>">
                                            <span data-menu-bg="<?= $specialization->background ?>" style="background: <?= $specialization->background ?>"></span><a href="#" data-id="<?= $specialization->specialization_id ?>" class="map_company_filter"><?= $specialization->specialization_name ?></a>
                                            <ul>
                                                <?php foreach($specialization->children as $child_first) { ?>
                                                    <li>
                                                        <a href="#" data-id="<?= $child_first->specialization_id ?>" class="map_company_filter"><?= $child_first->specialization_name ?></a>
                                                        <ul>
                                                            <?php foreach($child_first->children as $child_second) { ?>
                                                                <li>
                                                                    <a href="#" title="<?= $child_second->specialization_name ?>" data-id="<?= $child_second->specialization_id ?>" class="map_company_filter"><?= $child_second->specialization_name ?></a>
                                                                </li>
                                                            <?php } ?>
                                                        </ul>
                                                    </li>
                                                <?php } ?>
                                            </ul>
                                        </li>
                                        <?php
                                    }
                                ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php
    $this->endBlock();
    $this->beginBlock('blog');
    /**
     * Use $blogProvider for this block
     */
    if(!empty( $blogProvider->models )) {
        ?>
        <div class="section-box-232">
            <div class="box-wr">
                <div class="box-all">
                    <?php
                        echo ListView::widget([
                            'dataProvider' => $blogProvider,
                            'options'      => [
                                'class' => 'min-post-wr',
                            ],
                            'itemView'     => '_company_common_blog',
                            'itemOptions'  => [
                                'class' => 'min-post-block',
                            ],
                            'layout'       => '{items}',
                            'viewParams'   => [ 'parent_view' => $this ],
                        ]);
                    ?>
                </div>
            </div>
        </div>
        <?php
    }
    $this->endBlock();
    $this->beginBlock('team');
    /*
     * User preloaded $company->teams models
     */
    $teams = ArrayHelper::index($company->teams, 'team_id', 'department.name'); // Group team members according to their department
    if(!empty( $teams )) {
        ?>
        <div class="section-box-233">
            <div class="box-wr">
                <div class="box-all">
                    <div class="table-team-title style">Состав команды</div>
                    <div class="table-team-wr style">
                        <div class="table-team-left">
                            <?php
                                for($i = 0; $i < count($teams); $i = $i + 2) {
                                    ?>
                                    <div class="tb-team-wr">
                                        <table class="title-table" cellspacing="0" cellpadding="0" border="0">
                                            <tr>
                                                <td width="337">
                                                    <?php
                                                        if(!empty( array_keys($teams)[ $i ] )) {
                                                            echo array_keys($teams)[ $i ];
                                                        } else {
                                                            echo 'Не определен';
                                                        }
                                                    ?>
                                                </td>
                                                <td align="center"></td>
                                            </tr>
                                        </table>
                                        <table class="all-table-first" cellspacing="0" cellpadding="0" border="0">
                                            <tr>
                                                <td align="center" width="32"></td>
                                                <td align="center" width="323">Ф.И.О.</td>
                                                <td align="center" width="91">Опыт, лет</td>
                                            </tr>
                                        </table>
                                        <table class="all-table" cellspacing="0" cellpadding="0" border="0">
                                            <?php
                                                foreach($teams[ array_keys($teams)[ $i ] ] as $team) {
                                                    ?>
                                                    <tr>
                                                        <td align="center" width="32">
                                                            <?= Html::img('/images/portfolio-project/flag-img-1.jpg') ?>
                                                        </td>
                                                        <td align="center" width="323"><?= $team->lastname . ' ' . $team->firstname ?></td>
                                                        <td align="center" width="91">
                                                            <?php
                                                                if(!empty( $team->experience_from )) {
                                                                    echo date('Y') - $team->experience_from;
                                                                } else {
                                                                    echo 'Не указан';
                                                                }
                                                            ?>
                                                        </td>
                                                    </tr>
                                                    <?php
                                                }
                                            ?>
                                        </table>
                                    </div>
                                    <?php
                                }
                            ?>
                        </div>
                        <div class="table-team-right">
                            <?php
                                for($i = 1; $i < count($teams); $i = $i + 2) {
                                    ?>
                                    <div class="tb-team-wr">
                                        <table class="title-table" cellspacing="0" cellpadding="0" border="0">
                                            <tr>
                                                <td width="337">
                                                    <?php
                                                        if(!empty( array_keys($teams)[ $i ] )) {
                                                            echo array_keys($teams)[ $i ];
                                                        } else {
                                                            echo 'Не определен';
                                                        }
                                                    ?>
                                                </td>
                                                <td align="center"></td>
                                            </tr>
                                        </table>
                                        <table class="all-table-first" cellspacing="0" cellpadding="0" border="0">
                                            <tr>
                                                <td align="center" width="32"></td>
                                                <td align="center" width="323">Ф.И.О.</td>
                                                <td align="center" width="91">Опыт, лет</td>
                                            </tr>
                                        </table>
                                        <table class="all-table" cellspacing="0" cellpadding="0" border="0">
                                            <?php
                                                foreach($teams[ array_keys($teams)[ $i ] ] as $team) {
                                                    ?>
                                                    <tr>
                                                        <td align="center" width="32">
                                                            <?= Html::img('/images/portfolio-project/flag-img-1.jpg') ?>
                                                        </td>
                                                        <td align="center" width="323"><?= $team->lastname . ' ' . $team->firstname ?></td>
                                                        <td align="center" width="91">
                                                            <?php
                                                                if(!empty( $team->experience_from )) {
                                                                    echo date('Y') - $team->experience_from;
                                                                } else {
                                                                    echo 'Не указан';
                                                                }
                                                            ?>
                                                        </td>
                                                    </tr>
                                                    <?php
                                                }
                                            ?>
                                        </table>
                                    </div>
                                    <?php
                                }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
    $this->endBlock();
    $this->beginBlock('review');
    if(!empty( $commentProvider->models )) {
        ?>
        <div class="section-box-19">
            <div class="box-wr">
                <div class="box-all">
                    <div class="company-performer-comm-title style">Мнений: <?= $commentProvider->totalCount ?></div>
                    <?php
                        echo ListView::widget([
                            'dataProvider' => $commentProvider,
                            'options'      => [
                                'class' => 'company-performer-comments-wr style',
                            ],
                            'itemView'     => '_company_common_review',
                            'itemOptions'  => [
                                'class' => 'company-performer-comments-bl',
                            ],
                            'layout'       => '{items}',
                        ]);
                    ?>
                    <div class="company-performer-comm-see-all-butt style">
                        <?= Html::a('Читать все мнения', [
                            'company/review',
                            'company_id' => $company->id,
                            'type'       => ( !empty( $this->params[ 'type' ] ) ) ? $this->params[ 'type' ] : NULL,
                        ]) ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
    $this->endBlock();
    /*====End blocks for layout====*/
?>